import requests
url = 'https://api-v2.thaibulksms.com/sms'
def send_sms(apiKey, apiSerect, phone, message, sender='SMS.', scheduled_delivery='', force=''):
    r = requests.post(url, data={'msisdn': phone, 'message': message, 'sender': sender}, auth=(apiKey, apiSerect))
    return r



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name='thaibulksms_api',
    version='1.0.7',
    description='Thaibulksms API for send sms',
    author='thaibulksms_api',
    author_email='apichart@1moby.com',
    packages=['thaibulksms_api'],
    license="thaibulksms",
    #   url='https://github.com/morangesolution/bahttext',
    #   download_url='https://github.com/morangesolution/bahttext/tarball/master',
)
